Bibliography
============

Bibliography
------------

.. [Burdet2013] P. Burdet, J. Vannod, A. Hessler-Wyser, M. Rappaz, M. Cantoni,
   "Three-dimensional chemical analysis of laser-welded NiTi–stainless steel wires
   using a dual-beam FIB", Acta Materialia 61 (2013) 3090–3098.

.. [Candes2011] E. Candes, X. Li, Y. Ma and J. Wright, "Robust principal component analysis?"
   J. ACM 58(3) (2011) 1–37

.. [Chantler2015] http://physics.nist.gov/ffast

.. [Egerton2011] Ray Egerton, "Electron Energy-Loss Spectroscopy in the
   Electron Microscope", Springer-Verlag, 2011.

.. [Feng2013] J. Feng, H. Xu and S. Yan, "Online Robust PCA via Stochastic Optimization",
   NIPS 2013, 2013.

.. [Hyvarinen2000] A. Hyvarinen, E. Oja, "Independent component analysis: algorithms
   and applications", Neural Networks 13 (2000) 411–430.

.. [Keenan2004] Michael R. Keenan, Paul G. Kotula, "Accounting for Poisson noise
   in the multivariate analysis of ToF-SIMS spectrum images", Surf. Interface Anal
   36(3) (2004) 203–212.

.. [MacArthur2016] Katherine E. MacArthur, Thomas J. A. Slater, Sarah J. Haigh,
   Dogan Ozkaya, Peter D. Nellist, Sergio Lozano-Perez, "Quantitative
   Energy-Dispersive X-Ray Analysis of Catalyst Nanoparticles Using a Partial
   Cross Section Approach." Microsc. Microanal. 22 (2016) 71–81.
   doi:10.1017/S1431927615015494.

.. [Pena2010] F. de la Pena, M.-H. Berger, J.-F. Hochepid, F. Dynys, O. Stephan,
   M. Walls, "Mapping titanium and tin oxide phases using EELS: An application of
   independent component analysis", Ultramicroscopy 111 (2010) 169–176.

.. [Rossouw2015] David Rossouw, Pierre Burdet, Francisco de la Pena, Caterina
   Ducati, Benjamin R. Knappett, Andrew E. H. Wheatley, Paul A. Midgley, "Multicomponent
   Signal Unmixing from Nanoheterostructures: Overcoming the Traditional Challenges
   of Nanoscale X-ray Analysis via Machine Learning" Nano Lett. 15(4) (2015) 2716–2720

.. [Watanabe1996] Masashi Watanabe, Zenji Horita, Minoru Nemoto, "Absorption
   correction and thickness determination using the zeta factor in quantitative
   X-ray microanalysis." Ultramicroscopy 65 (1996) 187–198.

.. [Watanabe2006] Masashi Watanabe, David B. Williams, "The quantitative
   analysis of thin specimens: a review of progress from the Cliff-Lorimer to
   the new zeta-factor methods. J. Microsc. 221 (2006) 89–109.
   doi:10.1111/j.1365-2818.2006.01549.x.

.. [Williams2009] David B. Williams, Barry Carter, "Transmission Electron
   Microscopy: A Textbook for Materials Science (Part 4)", Second Edi, Springer,
   New York, 2009.

.. [Zhou2011] T. Zhou and D. Tao, "GoDec: Randomized Low-rank & Sparse Matrix
   Decomposition in Noisy Case", ICML-11 (2011) 33–40.

.. [Gabor1948] Gabor, Dennis. "A new microscopic principle." Nature 161.4098 (1948): 777-778.

.. [Tonomura1999] Tonomura, Akira. "Electron Holography." Springer Berlin Heidelberg, 1999. 78-132.

.. [McCartney2007] McCartney, Martha R., and David J. Smith. "Electron holography: phase imaging with nanometer resolution." Annu. Rev. Mater. Res. 37 (2007): 729-767.

.. [Joy1993] Joy, David C., et al. "Practical aspects of electron holography." Ultramicroscopy 51.1-4 (1993): 1-14.

.. [Zhao2016] Zhao, Renbo, and Vincent YF Tan. "Online nonnegative matrix factorization with outliers." Acoustics, Speech and Signal Processing (ICASSP), 2016 IEEE International Conference on. IEEE, 2016.


Peer-review articles with results obtained using HyperSpy
---------------------------------------------------------

.. note::

   Given the incresing number of articles that cite HyperSpy we no longer
   maintain a list of articles here. For an up to date list search for
   HyperSpy in a scientific database e.g. `Google Scholar
   <https://scholar.google.co.uk/scholar?hl=en&q=hyperspy&btnG=&as_sdt=1%2C5>`_.

.. Warning::
    The articles published before 2012 may mention the HyperSpy project under
    its old name, EELSLab
